@@ -15,13 +15,14 @@ module Rex
           # @param [Boolean] is_initiator Are we the initiator in this communication (used for setting flags and key usage values)
           # @param [Boolean] use_acceptor_subkey Are we using the subkey provided by the acceptor? (used for setting appropriate flags)
           # @param [Boolean] dce_style Is the format of the encrypted blob DCE-style?
-          def initialize(key, encrypt_sequence_number, decrypt_sequence_number, is_initiator: true, use_acceptor_subkey: true, dce_style: false)
+          def initialize(key, encrypt_sequence_number, decrypt_sequence_number, is_initiator: true, use_acceptor_subkey: true, dce_style: false, rc4_pad_style: :single_byte)
             @key = key
             @encrypt_sequence_number = encrypt_sequence_number
             @decrypt_sequence_number = decrypt_sequence_number
             @is_initiator = is_initiator
             @use_acceptor_subkey = use_acceptor_subkey
             @dce_style = dce_style
+            @rc4_pad_style = rc4_pad_style
             @encryptor = Rex::Proto::Kerberos::Crypto::Encryption::from_etype(key.type)
           end
   
@@ -30,7 +31,7 @@ module Rex
           # @return [String, Integer, Integer] The encrypted data, the length of its header, and the length of padding added to it prior to encryption
           #
           def encrypt_and_increment(data)
-            result = encryptor.gss_wrap(data, @key, @encrypt_sequence_number, @is_initiator, use_acceptor_subkey: @use_acceptor_subkey, dce_style: @dce_style)
+            result = encryptor.gss_wrap(data, @key, @encrypt_sequence_number, @is_initiator, use_acceptor_subkey: @use_acceptor_subkey, dce_style: @dce_style, rc4_pad_style: @rc4_pad_style)
             @encrypt_sequence_number += 1  
             
             result
@@ -41,7 +42,7 @@ module Rex
           #
           def decrypt_and_verify(data)
             result = encryptor.gss_unwrap(data, @key, @decrypt_sequence_number, @is_initiator, use_acceptor_subkey: @use_acceptor_subkey)
-            @decrypt_sequence_number += 1
+            @decrypt_sequence_number += 1 unless @decrypt_sequence_number.nil?
 
             result
           end
@@ -85,6 +86,19 @@ module Rex
           #
           attr_accessor :dce_style
 
+          #
+          # [Symbol] The RC4 spec (RFC4757) section 7.3 implies that RC4-HMAC only needs one byte of padding,
+          # although it doesn't come straight out and say it. Some protocols (LDAP, at least on a DC) complain
+          # if you give it more than a single byte of paddding.
+          # Other protocols (DRSR) complain if you don't align it perfectly with an 8-byte boundary.
+          # The MS-RPCE spec is a little vague on why exactly that might be, but we can at least
+          # show empirically that it is happy if you just give it an 8-byte aligned encrypted stub.
+          # Yet other protocols are happy whatever the padding (WinRM).
+          # Here, we allow customising the behaviour of the RC4-HMAC GSSAPI crypto scheme by providing either:
+          # - :single_byte -> Puts a single '\x01' byte of padding at the end
+          # - :eight_byte_aligned -> Puts between 1 and 8 bytes of PKCS#5 padding
+          attr_accessor :rc4_pad_style
+
           #
           # [Rex::Proto::Kerberos::Crypto::*] Encryption class for encrypting/decrypting messages
           #
