@@ -783,20 +783,20 @@ RSpec.describe Msf::Exploit::Remote::HTTP::HttpCookie do
     end
 
     it 'will return false if url with http protocol is passed but has no host' do
-      protcol = 'http://'
+      protocol = 'http://'
 
-      v = cookie.acceptable_from_uri?(protcol)
+      v = cookie.acceptable_from_uri?(protocol)
 
-      expect(URI(protcol).is_a?(::URI::HTTP)).to eq(true)
+      expect(URI(protocol).is_a?(::URI::HTTP)).to eq(true)
       expect(v).to eq(false)
     end
 
     it 'will return false if url with https protocol is passed but has no host' do
-      protcol = 'https://'
+      protocol = 'https://'
 
-      v = cookie.acceptable_from_uri?(protcol)
+      v = cookie.acceptable_from_uri?(protocol)
 
-      expect(URI(protcol).is_a?(::URI::HTTP)).to eq(true)
+      expect(URI(protocol).is_a?(::URI::HTTP)).to eq(true)
       expect(v).to eq(false)
     end
 
